// Adafruit IO IFTTT Example - Gmailbox
// Tutorial Link: https://learn.adafruit.com/gmailbox
//
// Adafruit invests time and resources providing this open source code.
// Please support Adafruit and open source hardware by purchasing
// products from Adafruit!
//
// Written by Brent Rubell for Adafruit Industries
// Copyright (c) 2018 Adafruit Industries
// Licensed under the MIT license.
//
// All text above must be included in any redistribution.

//MODIFIED BY LMJD14 TO CREATE LOCATION "CLOCK"

/************************** Configuration ***********************************/

// edit the config.h tab and enter your Adafruit IO credentials
// and any additional configuration needed for WiFi, cellular,
// or ethernet clients.
#include "config.h"

// Import Servo Libraries
#if defined(ARDUINO_ARCH_ESP32)
  // ESP32Servo Library (https://github.com/madhephaestus/ESP32Servo)
  // installation: library manager -> search -> "ESP32Servo"
  #include <ESP32Servo.h>
#else
  #include <Servo.h>
#endif

/************************ Example Starts Here *******************************/

// holds the current count value for our sketch

// pin used to control the servo
#define SERVO1_PIN 2
#define SERVO2_PIN 4

// Angle in degrees of "home" position
#define HOME_1 158
#define HOME_2 15

// Angle in degrees of "work" position
#define WORK_1 128
#define WORK_2 45

// Angle in degrees of "travelling" position
#define TRAVELLING_1 103
#define TRAVELLING_2 65

// Angle in degrees of "parents" position
#define PARENTS_1 80
#define PARENTS_2 97

//Angle in degrees of "uni" position
#define UNI 60

//Angle in degrees of "shopping" position
#define SHOPPING_1 40
#define SHOPPING_2 135

// Angle in degrees of "climbing" position
#define CLIMBING 7

// Angle in degrees of "dance" position
#define DANCE 177

// create an instance of the servo class
Servo servo1;
Servo servo2;

// set up the 'locations' feed
AdafruitIO_Feed *locations1 = io.feed("REPLACE WITH FIRST USER'S LOCATION FEED NAME");
AdafruitIO_Feed *locations2 = io.feed("REPLACE WITH SECOND USER'S LOCATION FEED NAME");

void setup() {

  // start the serial connection
  Serial.begin(115200);

  // wait for serial monitor to open
  while(! Serial);

  Serial.println();
  Serial.println("Two Person Weasley Clock");

  // tell the servo class which pin we are using
  servo1.attach(SERVO1_PIN);
  servo2.attach(SERVO2_PIN);

  // connect to io.adafruit.com
  Serial.println("Connecting to Adafruit IO");
  io.connect();

  // set up a message handler for the 'servo' feed.
  // the handleMessage function (defined below)
  // will be called whenever a message is
  // received from adafruit io.
  locations1->onMessage(handleMessage1);
  locations2->onMessage(handleMessage2);

  // wait for a connection
  while(io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  // we are connected
  Serial.println();
  Serial.println(io.statusText());

  // get current values from both feeds
  locations1->get();
  locations2->get();

}

void loop() {

  // io.run(); is required for all sketches.
  // it should always be present at the top of your loop
  // function. it keeps the client connected to
  // io.adafruit.com, and processes any incoming data.
  io.run();

  
}

// this function is called whenever a 'locations' message
// is received from Adafruit IO. it was attached to
// the locations feed in the setup() function above.
void handleMessage1(AdafruitIO_Data *data) {

  String commandStr = data->toString(); // store the incoming commands in a string

  // received message
  Serial.print("received (User 1) <- ");
  Serial.println(commandStr);
  
  //Check what the message we received was and move the arrow to point to that location
  if(commandStr == "HOME"){
    servo1.write(HOME_1);
  }else if (commandStr == "WORK") {
    servo1.write(WORK_1);
  }else if (commandStr == "TRAVELLING") {
    servo1.write(TRAVELLING_1);
  }else if (commandStr == "PARENTS"){
    servo1.write(PARENTS_1);
  }else if (commandStr == "UNI"){
    servo1.write(UNI);
  }else if (commandStr == "SHOPPING"){
    servo1.write(SHOPPING_1);
  }else if(commandStr == "CLIMBING"){
    servo1.write(CLIMBING);
  }else {
    servo1.write(TRAVELLING_1); //If we ever don't understand the message we received, default to travelling
  }
}

void handleMessage2(AdafruitIO_Data *data) {

  String commandStr = data->toString(); // store the incoming commands in a string

  // received message
  Serial.print("received (User 2) <- ");
  Serial.println(commandStr);
  
  if(commandStr == "HOME"){
    servo2.write(HOME_2);
  }else if (commandStr == "WORK") {
    servo2.write(WORK_2);
  }else if (commandStr == "TRAVELLING") {
    servo2.write(TRAVELLING_2);
  }else if (commandStr == "PARENTS"){
    servo2.write(PARENTS_2);
  }else if (commandStr == "SHOPPING"){
    servo2.write(SHOPPING_2);
  }else if(commandStr == "DANCE"){
    servo2.write(DANCE);
  }else {
    servo2.write(TRAVELLING_2);
  }
}
